@@ -9,16 +9,20 @@ import math
 import time
 import platform
 import warnings
-import collections
 
 # 3rd party
 import six
-import mock
 import pytest
 from six.moves import reload_module
 
 # local
-from .accessories import TestTerminal, all_terms, unicode_cap, as_subprocess
+from .accessories import TestTerminal, unicode_cap, as_subprocess
+from .conftest import IS_WINDOWS
+
+try:
+    from unittest import mock
+except ImportError:
+    import mock
 
 
 def test_export_only_Terminal():
@@ -87,7 +91,7 @@ def test_null_fileno():
     child()
 
 
-@pytest.mark.skipif(platform.system() == 'Windows', reason="requires more than 1 tty")
+@pytest.mark.skipif(IS_WINDOWS, reason="requires more than 1 tty")
 def test_number_of_colors_without_tty():
     """``number_of_colors`` should return 0 when there's no tty."""
     @as_subprocess
@@ -102,11 +106,8 @@ def test_number_of_colors_without_tty():
 
     @as_subprocess
     def child_8_forcestyle():
-        kind = 'ansi'
-        if platform.system().lower() == 'freebsd':
-            # 'ansi' on freebsd returns 0 colors, we use the 'cons25' driver,
-            # compatible with its kernel tty.c
-            kind = 'cons25'
+        # 'ansi' on freebsd returns 0 colors. We use 'cons25', compatible with its kernel tty.c
+        kind = 'cons25' if platform.system().lower() == 'freebsd' else 'ansi'
         t = TestTerminal(kind=kind, stream=six.StringIO(),
                          force_styling=True)
         assert (t.number_of_colors == 8)
@@ -123,7 +124,7 @@ def test_number_of_colors_without_tty():
     child_256_nostyle()
 
 
-@pytest.mark.skipif(platform.system() == 'Windows', reason="requires more than 1 tty")
+@pytest.mark.skipif(IS_WINDOWS, reason="requires more than 1 tty")
 def test_number_of_colors_with_tty():
     """test ``number_of_colors`` 0, 8, and 256."""
     @as_subprocess
@@ -133,11 +134,8 @@ def test_number_of_colors_with_tty():
 
     @as_subprocess
     def child_8():
-        kind = 'ansi'
-        if platform.system().lower() == 'freebsd':
-            # 'ansi' on freebsd returns 0 colors, we use the 'cons25' driver,
-            # compatible with its kernel tty.c
-            kind = 'cons25'
+        # 'ansi' on freebsd returns 0 colors. We use 'cons25', compatible with its kernel tty.c
+        kind = 'cons25' if platform.system().lower() == 'freebsd' else 'ansi'
         t = TestTerminal(kind=kind)
         assert (t.number_of_colors == 8)
 
@@ -191,8 +189,7 @@ def test_setupterm_singleton_issue_33():
         try:
             # a second instantiation raises UserWarning
             term = TestTerminal(kind=next_kind, force_styling=True)
-        except UserWarning:
-            err = sys.exc_info()[1]
+        except UserWarning as err:
             assert (err.args[0].startswith(
                     'A terminal of kind "' + next_kind + '" has been requested')
                     ), err.args[0]
@@ -200,7 +197,7 @@ def test_setupterm_singleton_issue_33():
                     'continue to be returned' in err.args[0]), err.args[0]
         else:
             # unless term is not a tty and setupterm() is not called
-            assert not term.is_a_tty or False, 'Should have thrown exception'
+            assert not term.is_a_tty, 'Should have thrown exception'
         warnings.resetwarnings()
 
     child()
@@ -219,8 +216,7 @@ def test_setupterm_invalid_issue39():
 
         try:
             term = TestTerminal(kind='unknown', force_styling=True)
-        except UserWarning:
-            err = sys.exc_info()[1]
+        except UserWarning as err:
             assert err.args[0] in (
                 "Failed to setupterm(kind='unknown'): "
                 "setupterm: could not find terminal",
@@ -255,29 +251,6 @@ def test_setupterm_invalid_has_no_styling():
     child()
 
 
-def test_missing_ordereddict_uses_module(monkeypatch):
-    """ordereddict module is imported when without collections.OrderedDict."""
-    import blessed.keyboard
-
-    if hasattr(collections, 'OrderedDict'):
-        monkeypatch.delattr('collections.OrderedDict')
-
-    try:
-        reload_module(blessed.keyboard)
-    except ImportError as err:
-        assert err.args[0] in ("No module named ordereddict",  # py2
-                               "No module named 'ordereddict'")  # py3
-        sys.modules['ordereddict'] = mock.Mock()
-        sys.modules['ordereddict'].OrderedDict = -1
-        reload_module(blessed.keyboard)
-        assert blessed.keyboard.OrderedDict == -1
-        del sys.modules['ordereddict']
-        monkeypatch.undo()
-        reload_module(blessed.keyboard)
-    else:
-        assert platform.python_version_tuple() < ('2', '7')  # reached by py2.6
-
-
 def test_python3_2_raises_exception(monkeypatch):
     """Test python version 3.0 through 3.2 raises an exception."""
     import blessed
@@ -306,7 +279,6 @@ def test_IOUnsupportedOperation():
     """Ensure stream that throws IOUnsupportedOperation results in non-tty."""
     @as_subprocess
     def child():
-        import blessed.terminal
 
         def side_effect():
             raise io.UnsupportedOperation
@@ -323,7 +295,7 @@ def test_IOUnsupportedOperation():
     child()
 
 
-@pytest.mark.skipif(platform.system() == 'Windows', reason="has process-wide side-effects")
+@pytest.mark.skipif(IS_WINDOWS, reason="has process-wide side-effects")
 def test_winsize_IOError_returns_environ():
     """When _winsize raises IOError, defaults from os.environ given."""
     @as_subprocess
@@ -370,7 +342,7 @@ def test_yield_hidden_cursor(all_terms):
     child(all_terms)
 
 
-@pytest.mark.skipif(platform.system() == 'Windows', reason="windows doesn't work like this")
+@pytest.mark.skipif(IS_WINDOWS, reason="windows doesn't work like this")
 def test_no_preferredencoding_fallback():
     """Ensure empty preferredencoding value defaults to ascii."""
     @as_subprocess
@@ -383,7 +355,7 @@ def test_no_preferredencoding_fallback():
     child()
 
 
-@pytest.mark.skipif(platform.system() == 'Windows', reason="requires fcntl")
+@pytest.mark.skipif(IS_WINDOWS, reason="requires fcntl")
 def test_unknown_preferredencoding_warned_and_fallback():
     """Ensure a locale without a codec emits a warning."""
     @as_subprocess
@@ -399,7 +371,7 @@ def test_unknown_preferredencoding_warned_and_fallback():
     child()
 
 
-@pytest.mark.skipif(platform.system() == 'Windows', reason="requires fcntl")
+@pytest.mark.skipif(IS_WINDOWS, reason="requires fcntl")
 def test_win32_missing_tty_modules(monkeypatch):
     """Ensure dummy exception is used when io is without UnsupportedOperation."""
     @as_subprocess
@@ -413,7 +385,7 @@ def test_win32_missing_tty_modules(monkeypatch):
 
         tty_modules = ('termios', 'fcntl', 'tty')
 
-        def __import__(name, *args, **kwargs):
+        def __import__(name, *args, **kwargs):  # pylint: disable=redefined-builtin
             if name in tty_modules:
                 raise ImportError
             return original_import(name, *args, **kwargs)
@@ -430,8 +402,7 @@ def test_win32_missing_tty_modules(monkeypatch):
             try:
                 import blessed.terminal
                 reload_module(blessed.terminal)
-            except UserWarning:
-                err = sys.exc_info()[1]
+            except UserWarning as err:
                 assert err.args[0] == blessed.terminal._MSG_NOSUPPORT
 
             warnings.filterwarnings("ignore", category=UserWarning)
@@ -477,7 +448,7 @@ def test_time_left_infinite_None():
     assert _time_left(stime=time.time(), timeout=None) is None
 
 
-@pytest.mark.skipif(platform.system() == 'Windows', reason="cant multiprocess")
+@pytest.mark.skipif(IS_WINDOWS, reason="cant multiprocess")
 def test_termcap_repr():
     """Ensure ``hidden_cursor()`` writes hide_cursor and normal_cursor."""
 
