@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+"""Tests for capturing keyboard input"""
+
 # std imports
 import os
 import sys
@@ -9,7 +11,6 @@ import platform
 
 # 3rd party
 import six
-import mock
 import pytest
 
 # local
@@ -22,15 +23,25 @@ from .accessories import (SEMAPHORE,
                           read_until_eof,
                           read_until_semaphore,
                           init_subproc_coverage)
+from.conftest import IS_WINDOWS, TEST_KEYBOARD, TEST_QUICK, TEST_RAW
+
+try:
+    from unittest import mock
+except ImportError:
+    import mock
+
+got_sigwinch = False
 
 pytestmark = pytest.mark.skipif(
-    os.environ.get('TEST_KEYBOARD', None) != 'yes' or platform.system() == 'Windows',
+    not TEST_KEYBOARD or IS_WINDOWS,
     reason="Timing-sensitive tests please do not run on build farms.")
 
-@pytest.mark.skipif(os.environ.get('TEST_QUICK', None) is not None,
-                    reason="TEST_QUICK specified")
+
+@pytest.mark.skipif(TEST_QUICK, reason="TEST_QUICK specified")
 def test_kbhit_interrupted():
     """kbhit() should not be interrupted with a signal handler."""
+    # pylint: disable=global-statement
+
     import pty
     pid, master_fd = pty.fork()
     if pid == 0:
@@ -71,10 +82,11 @@ def test_kbhit_interrupted():
     assert math.floor(time.time() - stime) == 1.0
 
 
-@pytest.mark.skipif(os.environ.get('TEST_QUICK', None) is not None,
-                    reason="TEST_QUICK specified")
+@pytest.mark.skipif(TEST_QUICK, reason="TEST_QUICK specified")
 def test_kbhit_interrupted_nonetype():
     """kbhit() should also allow interruption with timeout of None."""
+    # pylint: disable=global-statement
+
     import pty
     pid, master_fd = pty.fork()
     if pid == 0:
@@ -134,7 +146,6 @@ def test_kbhit_no_kb():
 
 def test_kbhit_no_tty():
     """kbhit() returns False immediately if HAS_TTY is False"""
-    import blessed.terminal
     @as_subprocess
     def child():
         with mock.patch('blessed.terminal.HAS_TTY', False):
@@ -171,8 +182,7 @@ def test_keystroke_0s_cbreak_noinput_nokb():
     child()
 
 
-@pytest.mark.skipif(os.environ.get('TEST_QUICK', None) is not None,
-                    reason="TEST_QUICK specified")
+@pytest.mark.skipif(TEST_QUICK, reason="TEST_QUICK specified")
 def test_keystroke_1s_cbreak_noinput():
     """1-second keystroke without input; '' should be returned after ~1 second."""
     @as_subprocess
@@ -186,8 +196,7 @@ def test_keystroke_1s_cbreak_noinput():
     child()
 
 
-@pytest.mark.skipif(os.environ.get('TEST_QUICK', None) is not None,
-                    reason="TEST_QUICK specified")
+@pytest.mark.skipif(TEST_QUICK, reason="TEST_QUICK specified")
 def test_keystroke_1s_cbreak_noinput_nokb():
     """1-second keystroke without input or keyboard."""
     @as_subprocess
@@ -367,8 +376,7 @@ def test_keystroke_0s_cbreak_sequence():
     assert math.floor(time.time() - stime) == 0.0
 
 
-@pytest.mark.skipif(os.environ.get('TEST_QUICK', None) is not None,
-                    reason="TEST_QUICK specified")
+@pytest.mark.skipif(TEST_QUICK, reason="TEST_QUICK specified")
 def test_keystroke_1s_cbreak_with_input():
     """1-second keystroke w/multibyte sequence; should return after ~1 second."""
     import pty
@@ -399,8 +407,7 @@ def test_keystroke_1s_cbreak_with_input():
     assert math.floor(time.time() - stime) == 1.0
 
 
-@pytest.mark.skipif(os.environ.get('TEST_QUICK', None) is not None,
-                    reason="TEST_QUICK specified")
+@pytest.mark.skipif(TEST_QUICK, reason="TEST_QUICK specified")
 def test_esc_delay_cbreak_035():
     """esc_delay will cause a single ESC (\\x1b) to delay for 0.35."""
     import pty
@@ -434,8 +441,7 @@ def test_esc_delay_cbreak_035():
     assert 34 <= int(duration_ms) <= 45, duration_ms
 
 
-@pytest.mark.skipif(os.environ.get('TEST_QUICK', None) is not None,
-                    reason="TEST_QUICK specified")
+@pytest.mark.skipif(TEST_QUICK, reason="TEST_QUICK specified")
 def test_esc_delay_cbreak_135():
     """esc_delay=1.35 will cause a single ESC (\\x1b) to delay for 1.35."""
     import pty
@@ -587,11 +593,11 @@ def test_get_location_0s():
 # jquast: having trouble with these tests intermittently locking up on Mac OS X 10.15.1,
 # that they *lock up* is troublesome, I tried to use "pytest-timeout" but this conflicts
 # with our retry module, so, just skip them entirely.
-@pytest.mark.skipif(not os.environ.get('TEST_RAW'), reason="TEST_RAW not specified")
+@pytest.mark.skipif(not TEST_RAW, reason="TEST_RAW not specified")
 def test_get_location_0s_under_raw():
     """0-second get_location call without response under raw mode."""
     import pty
-    pid, master_fd = pty.fork()
+    pid, _ = pty.fork()
     if pid == 0:
         cov = init_subproc_coverage('test_get_location_0s_under_raw')
         term = TestTerminal()
@@ -612,11 +618,11 @@ def test_get_location_0s_under_raw():
     assert math.floor(time.time() - stime) == 0.0
 
 
-@pytest.mark.skipif(not os.environ.get('TEST_RAW'), reason="TEST_RAW not specified")
+@pytest.mark.skipif(not TEST_RAW, reason="TEST_RAW not specified")
 def test_get_location_0s_reply_via_ungetch_under_raw():
     """0-second get_location call with response under raw mode."""
     import pty
-    pid, master_fd = pty.fork()
+    pid, _ = pty.fork()
     if pid == 0:
         cov = init_subproc_coverage('test_get_location_0s_reply_via_ungetch_under_raw')
         term = TestTerminal()
@@ -658,6 +664,7 @@ def test_get_location_0s_reply_via_ungetch():
 def test_get_location_0s_nonstandard_u6():
     """u6 without %i should not be decremented."""
     from blessed.formatters import ParameterizingString
+
     @as_subprocess
     def child():
         term = TestTerminal(stream=six.StringIO())
@@ -705,79 +712,11 @@ def test_get_location_timeout():
     child()
 
 
-def test_kbhit_no_kb():
-    """kbhit() always immediately returns False without a keyboard."""
-    @as_subprocess
-    def child():
-        term = TestTerminal(stream=six.StringIO())
-        stime = time.time()
-        assert term._keyboard_fd is None
-        assert not term.kbhit(timeout=1.1)
-        assert math.floor(time.time() - stime) == 1.0
-    child()
-
-
-def test_keystroke_0s_cbreak_noinput():
-    """0-second keystroke without input; '' should be returned."""
-    @as_subprocess
-    def child():
-        term = TestTerminal()
-        with term.cbreak():
-            stime = time.time()
-            inp = term.inkey(timeout=0)
-            assert (inp == u'')
-            assert (math.floor(time.time() - stime) == 0.0)
-    child()
-
-
-def test_keystroke_0s_cbreak_noinput_nokb():
-    """0-second keystroke without data in input stream and no keyboard/tty."""
-    @as_subprocess
-    def child():
-        term = TestTerminal(stream=six.StringIO())
-        with term.cbreak():
-            stime = time.time()
-            inp = term.inkey(timeout=0)
-            assert (inp == u'')
-            assert (math.floor(time.time() - stime) == 0.0)
-    child()
-
-
-@pytest.mark.skipif(os.environ.get('TEST_QUICK', None) is not None,
-                    reason="TEST_QUICK specified")
-def test_keystroke_1s_cbreak_noinput():
-    """1-second keystroke without input; '' should be returned after ~1 second."""
-    @as_subprocess
-    def child():
-        term = TestTerminal()
-        with term.cbreak():
-            stime = time.time()
-            inp = term.inkey(timeout=1)
-            assert (inp == u'')
-            assert (math.floor(time.time() - stime) == 1.0)
-    child()
-
-
-@pytest.mark.skipif(os.environ.get('TEST_QUICK', None) is not None,
-                    reason="TEST_QUICK specified")
-def test_keystroke_1s_cbreak_noinput_nokb():
-    """1-second keystroke without input or keyboard."""
-    @as_subprocess
-    def child():
-        term = TestTerminal(stream=six.StringIO())
-        with term.cbreak():
-            stime = time.time()
-            inp = term.inkey(timeout=1)
-            assert (inp == u'')
-            assert (math.floor(time.time() - stime) == 1.0)
-    child()
-
-
 @pytest.mark.skipif(six.PY2, reason="Python 3 only")
 def test_detached_stdout():
     """Ensure detached __stdout__ does not raise an exception"""
     import pty
-    pid, master_fd = pty.fork()
+    pid, _ = pty.fork()
     if pid == 0:
         cov = init_subproc_coverage('test_detached_stdout')
         sys.__stdout__.detach()
